<?php

abstract class BaseRuleReport
{
    public const ALL_TYPE = 'all';
    public const PASSING_TYPE = 'passing';
    public const FAILING_TYPE = 'failing';

    protected $conditionMustBeMet;
    protected $type;

    protected $defaultColumns = [
        'Hosts.HostName AS "Host name"',
        'Hosts.IPAddress AS "IP address"',
        'Hosts.LastReportTimeStamp AS "Last report time"'
    ];

    public function __construct($conditionMustBeMet, $type)
    {
        $this->conditionMustBeMet = $conditionMustBeMet;
        $this->type = $type;

        if ($type === self::ALL_TYPE) {
            $this->addResultColumn();
        }
    }

    abstract public function getReportSql($sql, CF_Rule $rule);

    /**
     * @param $sql
     * @return string
     */
    protected function getFilter($sql)
    {
        // if $type is all then join condition sql to show if a host is failing or passing
        return $this->type === self::ALL_TYPE ?
            "FULL OUTER JOIN ($sql) q2 ON q2.hostkey = Hosts.HostKey" :
            'WHERE Hosts.HostKey ' . ($this->conditionMustBeMet ? 'NOT IN' : 'IN') . " ($sql)";
    }

    /**
     * @return  void
     */
    protected function addResultColumn()
    {
        if ($this->conditionMustBeMet) {
            $then = self::FAILING_TYPE;
            $else = self::PASSING_TYPE;
        } else {
            $then = self::PASSING_TYPE;
            $else = self::FAILING_TYPE;
        }

        array_unshift($this->defaultColumns, "CASE WHEN q2.hostkey IS NULL THEN '$then' ELSE '$else' END AS \"Compliance\"");
    }
}
